@@ -108,8 +108,8 @@ inline double computeSquaredDifference(
   for (unsigned int d = 0; d < v.size(); ++d) {
     v[d] = (u[d] - v[d]) * static_cast<int>(activeAxis[d]);
   }
-  // @todo: this can be replaced by std::hypot when moving to C++17
-  return std::accumulate(v.begin(), v.end(), static_cast<double>(0.), [](auto &res, auto &val) { return res + val * val; });
+  // use std::inner_product to avoid the need for lambda expressions
+  return std::inner_product(v.begin(), v.end(), v.begin(), 0.0);
 }
 
 /// given the active axis, computes sets the axis with the lowest spatial expansion to dead
