@@ -1,9 +1,7 @@
 #pragma once
 
-namespace precice {
-namespace math {
+namespace precice::math {
 
 constexpr double PI = 3.1415926535897931;
 
 }
-} // namespace precice
