@@ -2,12 +2,11 @@
 
 #include "cplscheme/ParallelCouplingScheme.hpp"
 
-namespace precice {
-namespace testing {
+namespace precice::testing {
 /*
  * @brief A fixture that is used to access private functions of the ParallelCouplingScheme class.
  *
- * The fixture can be used to call private functions for individual testing. 
+ * The fixture can be used to call private functions for individual testing.
  */
 struct ParallelCouplingSchemeFixture {
   static bool isImplicitCouplingScheme(cplscheme::ParallelCouplingScheme &cplscheme);
@@ -15,6 +14,13 @@ struct ParallelCouplingSchemeFixture {
   static cplscheme::CouplingData *getReceiveData(cplscheme::ParallelCouplingScheme &cplscheme, int dataID);
 
   static cplscheme::CouplingData *getSendData(cplscheme::ParallelCouplingScheme &cplscheme, int dataID);
+
+  static void setTimeWindows(cplscheme::ParallelCouplingScheme &cplscheme, int timeWindows);
+
+  static void storeIteration(cplscheme::ParallelCouplingScheme &cplscheme);
+
+  static void initializeAcceleration(cplscheme::ParallelCouplingScheme &cplscheme);
+
+  static void moveToNextWindow(cplscheme::ParallelCouplingScheme &cplscheme);
 };
-} // namespace testing
-} // namespace precice
+} // namespace precice::testing
