@@ -6,24 +6,29 @@
 #pragma once
 
 #include <string>
+#include <string_view>
 
 #include "fmt/format.h"
 #include "fmt/ostream.h"
 #include "utils/fmtEigen.hpp"
 #include "utils/fmtSTL.hpp"
 
-namespace precice {
-namespace utils {
+namespace precice::utils {
+
+// pass through for string only
+inline std::string format_or_error(std::string_view str)
+{
+  return std::string{str};
+}
 
 template <class... A>
-std::string format_or_error(A &&... args)
+std::string format_or_error(std::string_view fmt, A &&...args)
 {
   try {
-    return fmt::format(std::forward<A>(args)...);
+    return fmt::vformat(fmt, fmt::make_format_args(args...));
   } catch (const fmt::format_error &e) {
     return std::string{"fmt_error: "} + e.what();
   }
 }
 
-} // namespace utils
-} // namespace precice
+} // namespace precice::utils
